@@ -763,8 +763,7 @@ class Script:
             profilefile.write('if [ ! -d  "${WORKING_DIR}" ]; then\n')
             profilefile.write('  mkdir ${WORKING_DIR}\n')
             profilefile.write('fi\n')
-            if self.queue_system is None:
-                profilefile.write('cd ${WORKING_DIR}\n')
+            profilefile.write('cd ${WORKING_DIR}\n')
             profilefile.write('\n')
 
             if self.likwid:
@@ -790,7 +789,7 @@ class Script:
         to_write = [a for a in dir(self.obj_options) if not a.startswith('__') and
                     not callable(getattr(self.obj_options, a))]
         for option in to_write:
-            if option is not None:
+            if option is not None and option != 'workdir':
                 profilefile.write(self.option_start + self.option_converter(option) +
                                   self.obj_options.__getattribute__(option) + '\n')
         profilefile.write('\n')
